@@ -26,7 +26,6 @@
 #include <algorithm>
 #include <stdlib.h>
 
-#include "safeunistd.h"
 #include "pathut.h"
 #include "execmd.h"
 #include "log.h"
@@ -98,7 +97,7 @@ bool Aspell::init(string &reason)
 #endif // WIN32
     
     const char *aspell_prog_from_env = getenv("ASPELL_PROG");
-    if (aspell_prog_from_env && access(aspell_prog_from_env, X_OK) == 0) {
+    if (aspell_prog_from_env && path_access(aspell_prog_from_env, X_OK) == 0) {
         m_data->m_execbuild = aspell_prog_from_env;
     }
 #ifdef ASPELL_PROG
@@ -283,7 +282,8 @@ bool Aspell::buildDict(Rcl::Db &db, string &reason)
                 cmdstring + "\n"
                 "One possible reason might be missing language "
                 "data files for lang = " + m_lang +
-                ". Maybe try to execute the command by hand for a better diag.";
+                ". Maybe try to execute the command on a terminal command line "
+                "for a better diagnostic.";
         }
         return false;
     }
