@@ -79,10 +79,10 @@ public:
     // Accept word and its position. If word is search term, add
     // highlight zone definition. If word is part of search group
     // (phrase or near), update positions list.
-    virtual bool takeword(const std::string& term, int pos, int bts, int bte) {
+    virtual bool takeword(const std::string& term, size_t pos, size_t bts, size_t bte) override {
         string dumb = term;
         if (o_index_stripchars) {
-            if (!unacmaybefold(term, dumb, "UTF-8", UNACOP_UNACFOLD)) {
+            if (!unacmaybefold(term, dumb, UNACOP_UNACFOLD)) {
                 LOGINFO("PlainToRich::takeword: unac failed for [" << term << "]\n");
                 return true;
             }
@@ -101,7 +101,7 @@ public:
         if (m_gterms.find(dumb) != m_gterms.end()) {
             // Term group (phrase/near) handling
             m_plists[dumb].push_back(pos);
-            m_gpostobytes[pos] = pair<int,int>(bts, bte);
+            m_gpostobytes[pos] = {bts, bte};
             LOGDEB1("Group term [" << dumb << "] at pos " << pos <<
                     " bytepos(" << bts << ", " << bte << ")\n");
         }
@@ -129,8 +129,8 @@ private:
     const HighlightData& m_hdata;
 
     // group/near terms word positions.
-    unordered_map<string, vector<int> > m_plists;
-    unordered_map<int, pair<int, int> > m_gpostobytes;
+    unordered_map<string, vector<size_t> > m_plists;
+    unordered_map<size_t, pair<size_t, size_t> > m_gpostobytes;
 };
 
 
@@ -205,9 +205,6 @@ bool PlainToRich::plaintorich(
     out.push_back("");
     auto olit = out.begin();
 
-    // Rich text output
-    *olit = header();
-    
     // No term matches. Happens, for example on a snippet selected for
     // a term match when we are actually looking for a group match
     // (the snippet generator does this...).
@@ -244,6 +241,9 @@ bool PlainToRich::plaintorich(
     // My tag state
     int inrcltag = 0;
 
+    // If the input is plain text we trust our user to have set up a proper beginning for the
+    // document. Else, we expect a header appropriate for inserting at the end of the <head>
+    // section, and will insert it there.
     string::size_type headend = 0;
     if (m_inputhtml) {
         headend = in.find("</head>");
@@ -251,6 +251,9 @@ bool PlainToRich::plaintorich(
             headend = in.find("</HEAD>");
         if (headend != string::npos)
             headend += 7;
+    } else {
+        // Rich text output
+        *olit = header();
     }
 
     for (string::size_type pos = 0; pos != string::npos; pos = chariter++) {
@@ -259,22 +262,27 @@ bool PlainToRich::plaintorich(
             CancelCheck::instance().checkCancel();
         }
 
+        if (m_inputhtml && headend != string::npos && chariter.getBpos() == headend - 7) {
+            // Insert the header text at the end of the <head> section.
+            *olit += header();
+        }
+
         // If we still have terms positions, check (byte) position. If
         // we are at or after a term match, mark.
         if (tPosIt != tPosEnd) {
-            int ibyteidx = int(chariter.getBpos());
+            auto ibyteidx = chariter.getBpos();
             if (ibyteidx == tPosIt->offs.first) {
-                if (!intag && ibyteidx >= (int)headend) {
-                    *olit += startMatch((unsigned int)(tPosIt->grpidx));
+                if (!intag && ibyteidx >= headend) {
+                    *olit += startMatch(static_cast<unsigned int>(tPosIt->grpidx));
                 }
                 inrcltag = 1;
             } else if (ibyteidx == tPosIt->offs.second) {
                 // Output end of match region tags
-                if (!intag && ibyteidx > (int)headend) {
+                if (!intag && ibyteidx > headend) {
                     *olit += endMatch();
                 }
                 // Skip all highlight areas that would overlap this one
-                int crend = tPosIt->offs.second;
+                auto crend = tPosIt->offs.second;
                 while (tPosIt != splitter.m_tboffs.end() && tPosIt->offs.first < crend)
                     tPosIt++;
                 inrcltag = 0;
