@@ -5,7 +5,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 from builtins import range
-import sys, struct, math, zipfile, io
+import sys, os, struct, math, zipfile, io
 from . import xmlpp
 
 PY3 = sys.version > '3'
@@ -66,6 +66,7 @@ class Params(object):
         self.noRawDump = False
         self.catchExceptions = False
         self.utf8 = False
+        self.oleConsistency = True
         
 # Global parameters / run configuration, to be set up by the main
 # program during initialization
