@@ -37,6 +37,12 @@
 
 using namespace std;
 
+// Some document types have losely defined MIME types, about which xdg-mime, file, and libmagic may
+// differ. Map them to our own choice.
+static std::map<std::string, std::string> mimealiases{
+    {"text/xml", "application/xml"}, // libmagic wrong. We right: rfc7303
+};
+
 /// Identification of file from contents. This is called for files with
 /// unrecognized extensions.
 ///
@@ -50,7 +56,6 @@ using namespace std;
 /// current/interesting file types.
 /// As a last resort we execute 'file' or its configured replacement
 /// (except if forbidden by config)
-
 static string mimetypefromdata(RclConfig *cfg, const string &fn, bool usfc)
 {
     LOGDEB1("mimetypefromdata: fn [" << fn << "]\n");
@@ -156,23 +161,26 @@ static string mimetypefromdata(RclConfig *cfg, const string &fn, bool usfc)
 
 #endif // Not libmagic
 
+    auto it = mimealiases.find(mime);
+    if (it != mimealiases.end())
+        return it->second;
     return mime;
 }
 
 // Guess mime type, first from suffix, then from file data. We also have a list of suffixes that we
 // don't touch at all.
-string mimetype(const string &fn, const struct PathStat *stp, RclConfig *cfg, bool usfc)
+string mimetype(const string &fn, RclConfig *cfg, bool usfc, const struct PathStat& stp)
 {
     // Use stat data if available to check for non regular files
-    if (stp) {
-        if (stp->pst_type == PathStat::PST_DIR)
+    if (stp.pst_type != PathStat::PST_INVALID) {
+        if (stp.pst_type == PathStat::PST_DIR)
             return "inode/directory";
-        if (stp->pst_type == PathStat::PST_SYMLINK)
+        if (stp.pst_type == PathStat::PST_SYMLINK)
             return "inode/symlink";
-        if (stp->pst_type != PathStat::PST_REGULAR)
+        if (stp.pst_type != PathStat::PST_REGULAR)
             return "inode/x-fsspecial";
         // Empty files are just this: avoid further errors with actual filters.
-        if (stp->pst_size == 0) 
+        if (stp.pst_size == 0) 
             return "inode/x-empty";
     }
 
@@ -210,7 +218,7 @@ string mimetype(const string &fn, const struct PathStat *stp, RclConfig *cfg, bo
 
     // If the type was not determined from the suffix, examine file data. Can only do this if we
     // have an actual file (as opposed to a pure name).
-    if (mtype.empty() && stp)
+    if (mtype.empty() && stp.pst_type != PathStat::PST_INVALID)
         mtype = mimetypefromdata(cfg, fn, usfc);
 
     return mtype;
