@@ -279,7 +279,6 @@ bool WebQueueIndexer::index()
             if (!eof)
                 return false;
         }
-        int nentries = 0;
         if (!eof) do {
                 string udi;
                 if (!cc->getCurrentUdi(udi)) {
@@ -302,7 +301,6 @@ bool WebQueueIndexer::index()
                         return false;
                     }
                 }
-                nentries++;
             } while (cc->next(eof));
     }
 
@@ -429,7 +427,7 @@ WebQueueIndexer::processone(
     }
 
     LOGDEB("WebQueueIndexer::processone: UDI: " << udipath << "\n");
-    make_udi(udipath, cstr_null, udi);
+    fileUdi::make_udi(udipath, cstr_null, udi);
 
     LOGDEB("WebQueueIndexer::processone: udi [" << udi << "]\n");
     ascdate = lltodecstr(stp.pst_mtime);
