@@ -28,11 +28,66 @@
 #include "rcldoc.h"
 #include "execmd.h"
 #include "conftree.h"
-
 using std::string;
 using std::map;
 using std::vector;
 
+#ifdef __APPLE__
+#include "transcode.h"
+#include "finderxattr.h"
+
+string decode_finder_metadata(const string& path, const string& xkey, const string& value)
+{
+    if (xkey == "com.apple.metadata:kMDItemFinderComment") {
+        auto [v1, error] = decode_comment_plist(
+            (const unsigned char *)value.c_str(), (int)value.size());
+        if (!error.empty()) {
+            LOGINF("reapXattrs: failed decoding finder comment for " << path << "\n");
+            return string();
+        } else {
+            if (!v1.empty() && v1[0] == 0) {
+                string v2;
+                transcode(v1, v2, "UCS-2BE", cstr_utf8);
+                return v2;
+            } else {
+                return v1;
+            }
+        }
+    } else if (xkey == "com.apple.metadata:_kMDItemUserTags") {
+        auto [v1, error] = decode_tags_plist(
+            (const unsigned char *)value.c_str(), (int)value.size());
+        if (!error.empty()) {
+            LOGINF("reapXattrs: failed decoding finder tags for " << path << "\n");
+            return string();
+        } else if (v1.empty()) {
+            return string();
+        } else {
+            // The tags have a color number at the end, which we discard as not interesting.
+            string nvalue;
+            for (auto& _s : v1) {
+                string s;
+                if (!_s.empty() && _s[0] == 0) {
+                    transcode(_s, s, "UCS-2BE", cstr_utf8);
+                } else {
+                    _s.swap(s);
+                }
+                auto pos = s.find_last_of(" \t\n\r");
+                if (pos != string::npos && pos < s.size() - 1) {
+                    if (isdigit(s[pos+1])) {
+                        s.erase(pos);
+                    }
+                }
+                trimstring(s, " \t\r\n");
+                nvalue += s + " ";
+            }
+            trimstring(nvalue, " \t\r\n");
+            return nvalue;
+        }
+    }
+    return string();
+}
+#endif // __APPLE__
+
 static void docfieldfrommeta(RclConfig* cfg, const string& name, const string &value, Rcl::Doc& doc)
 {
     string fieldname = cfg->fieldCanon(name);
@@ -40,19 +95,24 @@ static void docfieldfrommeta(RclConfig* cfg, const string& name, const string &v
     if (fieldname == cstr_dj_keymd) {
         doc.dmtime = value;
     } else {
-        doc.meta[fieldname] = value;
+        doc.addmeta(fieldname, value);
     }
 }
 
 void reapXAttrs(const RclConfig* cfg, const string& path,  map<string, string>& xfields)
 {
+#ifdef _WIN32
+    PRETEND_USE(cfg);
+    PRETEND_USE(path);
+    PRETEND_USE(xfields);
+#endif
     LOGDEB2("reapXAttrs: [" << path << "]\n");
-#ifndef _WIN32
+    
     // Retrieve xattrs names from files and mapping table from config
     vector<string> xnames;
     if (!pxattr::list(path, &xnames)) {
         if (errno == ENOTSUP) {
-            LOGDEB("FileInterner::reapXattrs: pxattr::list: errno " << errno << "\n");
+            LOGDEB("FileInterner::reapXattrs: pxattr::list: errno ENOTSUP\n");
         } else {
             LOGSYSERR("FileInterner::reapXattrs", "pxattr::list", path);
         }
@@ -60,9 +120,8 @@ void reapXAttrs(const RclConfig* cfg, const string& path,  map<string, string>&
     }
     const map<string, string>& xtof = cfg->getXattrToField();
 
-    // Record the xattrs: names found in the config are either skipped
-    // or mapped depending if the translation is empty. Other names
-    // are recorded as-is
+    // Record the xattrs: names found in the config are either skipped or mapped depending if the
+    // translation is empty. Other names are recorded as-is
     for (const auto& xkey : xnames) {
         string key = xkey;
         auto mit = xtof.find(xkey);
@@ -78,15 +137,20 @@ void reapXAttrs(const RclConfig* cfg, const string& path,  map<string, string>&
             LOGSYSERR("FileInterner::reapXattrs", "pxattr::get", path + " : " + xkey);
             continue;
         }
+
+#ifdef __APPLE__
+        static const string applemetastr("com.apple.metadata:");
+        if (beginswith(xkey, applemetastr)) {
+            value = decode_finder_metadata(path, xkey, value);
+        }
+#endif // __APPLE__
+
+        if (value.empty())
+            continue;
         // Encode should we ?
-        xfields[key] = value;
+        addmeta(xfields, key, value);
         LOGDEB2("reapXAttrs: [" << key << "] -> [" << value << "]\n");
     }
-#else
-    PRETEND_USE(cfg);
-    PRETEND_USE(path);
-    PRETEND_USE(xfields);
-#endif
 }
 
 void docFieldsFromXattrs(RclConfig *cfg, const map<string, string>& xfields, Rcl::Doc& doc)
