@@ -120,9 +120,8 @@ public slots:
     virtual void showAboutDialog();
     virtual void showMissingHelpers();
     virtual void showActiveTypes();
-    virtual void startManual();
     virtual void startOnlineManual();
-    virtual void startManual(const std::string&);
+    virtual void startManual(const std::string& = std::string());
     virtual void showDocHistory();
     virtual void showExtIdxDialog();
     virtual void setSynEnabled(bool);
@@ -146,7 +145,7 @@ public slots:
     virtual void startPreview(int docnum, Rcl::Doc doc, int keymods);
     virtual void startPreview(Rcl::Doc);
     virtual void startNativeViewer(Rcl::Doc, int pagenum = -1, QString term = QString(),
-                                   int line = -1);
+                                   int line = -1, bool enterHistory=true);
     virtual void openWith(Rcl::Doc, std::string);
     virtual void saveDocToFile(Rcl::Doc);
     virtual void populateSideFilters(SideFilterUpdateReason);
