@@ -59,6 +59,7 @@
 #include "appformime.h"
 #include "respopup.h"
 #include "reslistpager.h"
+#include "rclwebpage.h"
 
 using std::string;
 using std::vector;
@@ -112,18 +113,6 @@ function saveLoc(ev)
 }
 )raw");
 
-bool RclWebPage::acceptNavigationRequest(const QUrl& url, NavigationType tp, bool isMainFrame)
-{ 
-    Q_UNUSED(isMainFrame);
-    LOGDEB0("QWebEnginePage::acceptNavigationRequest. Type: " <<
-            tp << " isMainFrame " << isMainFrame << std::endl);
-    if (tp == QWebEnginePage::NavigationTypeLinkClicked) {
-        m_reslist->onLinkClicked(url);
-        return false;
-    } else {
-        return true;
-    }
-}
 #endif // WEBENGINE
 
 
@@ -140,21 +129,13 @@ public:
     virtual string nextUrl() override;
     virtual string prevUrl() override;
     virtual string headerContent() override;
-    virtual void suggest(const vector<string>uterms, 
-                         map<string, vector<string> >& sugg) override;
+    virtual void suggest(const vector<string>uterms, map<string, vector<string> >& sugg) override;
     virtual string absSep() override {return (const char *)(prefs.abssep.toUtf8());}
     virtual bool useAll() override {return prefs.useDesktopOpen;} 
 #if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
-    // We used to use http://localhost/. Now use file:/// as this is
-    // what Webengine will prepend relative links with (as
-    // baseURL). This is for the case where a user adds a link like
-    // P%N, which would not work if linkPrefix and baseURL were not
-    // the same.
-    //
-    // Now also set for webkit because, as we set baseURL to file://,
-    // the relative links we set in the list will also be prefixed (by
-    // the HTML engine)
-    virtual string linkPrefix() override {return "file:///recoll-links/";}
+    // We now set baseURL to file:///, The relative links will be received as e.g. file:///E%N we
+    // don't set the linkPrefix() anymore (it was "file:///recoll-links/" at some point but this
+    // broke links added by users).
     virtual string bodyAttrs() override {
         return "onload=\"addEventListener('contextmenu', saveLoc)\"";
     }
@@ -200,10 +181,7 @@ string QtGuiResListPager::trans(const string& in)
 
 string QtGuiResListPager::detailsLink()
 {
-    string chunk = string("<a href=\"") + linkPrefix() + "H-1\">";
-    chunk += trans("(show query)");
-    chunk += "</a>";
-    return chunk;
+    return href("H-1", trans("(show query)"));
 }
 
 const string& QtGuiResListPager::parFormat()
@@ -240,8 +218,7 @@ string QtGuiResListPager::headerContent()
 void QtGuiResListPager::suggest(const vector<string>uterms, map<string, vector<string>>& sugg)
 {
     sugg.clear();
-    bool issimple = m_reslist && m_reslist->m_rclmain && 
-        m_reslist->m_rclmain->lastSearchSimple();
+    bool issimple = m_reslist && m_reslist->m_rclmain && m_reslist->m_rclmain->lastSearchSimple();
 
     for (const auto& userterm : uterms) {
         vector<string> spellersuggs;
@@ -270,8 +247,7 @@ void QtGuiResListPager::suggest(const vector<string>uterms, map<string, vector<s
                 if (issimple) {
                     // If this is a simple search, we set up links as a <href="Sold|new">, else we
                     // just list the replacements.
-                    subst = string("<a href=\"") + linkPrefix() + "S" + userterm +
-                        "|" + subst + "\">" + subst + "</a>";
+                    subst = href("S-1|" + userterm + "|" + subst, subst);
                 }
                 sugg[userterm].push_back(subst);
             }
@@ -283,19 +259,16 @@ void QtGuiResListPager::suggest(const vector<string>uterms, map<string, vector<s
 
 string PlainToRichQtReslist::startMatch(unsigned int idx)
 {
-    (void)idx;
+    PRETEND_USE(idx);
 #if 0
     if (m_hdata) {
         string s1, s2;
         stringsToString<vector<string> >(m_hdata->groups[idx], s1); 
-        stringsToString<vector<string> >(
-            m_hdata->ugroups[m_hdata->grpsugidx[idx]], s2);
-        LOGDEB2("Reslist startmatch: group " << s1 << " user group " <<
-                s2 << "\n");
+        stringsToString<vector<string> >(m_hdata->ugroups[m_hdata->grpsugidx[idx]], s2);
+        LOGDEB2("Reslist startmatch: group " << s1 << " user group " << s2 << "\n");
     }
 #endif                
-    return string("<span class='rclmatch' style='")
-        + qs2utf8s(prefs.qtermstyle) + string("'>");
+    return string("<span class='rclmatch' style='") + qs2utf8s(prefs.qtermstyle) + string("'>");
 }
 
 string PlainToRichQtReslist::endMatch()
@@ -316,7 +289,6 @@ ResList::ResList(QWidget* parent, const char* name)
         setObjectName(name);
     
 #if defined(USING_WEBKIT) || defined(USING_WEBENGINE)
-    setPage(new RclWebPage(this));
     settings()->setAttribute(QWEBSETTINGS::JavascriptEnabled, true);
 #ifdef USING_WEBKIT
     LOGDEB("Reslist: using Webkit\n");
@@ -325,6 +297,8 @@ ResList::ResList(QWidget* parent, const char* name)
     connect(this, SIGNAL(linkClicked(const QUrl &)), this, SLOT(onLinkClicked(const QUrl &)));
 #else
     LOGDEB("Reslist: using Webengine\n");
+    setPage(new RclWebPage(this));
+    connect(page(), SIGNAL(linkClicked(const QUrl &)), this, SLOT(onLinkClicked(const QUrl &)));
     connect(page(), SIGNAL(loadFinished(bool)), this, SLOT(runStoredJS(bool)));
     // These appear to get randomly disconnected or never connected.
     connect(page(), SIGNAL(scrollPositionChanged(const QPointF &)),
@@ -342,7 +316,6 @@ ResList::ResList(QWidget* parent, const char* name)
     connect(this, SIGNAL(anchorClicked(const QUrl &)), this, SLOT(onLinkClicked(const QUrl &)));
 #endif
 
-    setFont();
     languageChange();
 
     (void)new HelpClient(this);
@@ -413,7 +386,7 @@ void ResList::runJS(const QString& js)
 #if defined(USING_WEBKIT)
     page()->mainFrame()->evaluateJavaScript(js);
 #elif defined(USING_WEBENGINE)
-        page()->runJavaScript(js);
+    page()->runJavaScript(js);
 //    page()->runJavaScript(js, [](const QVariant &v) {qDebug() << v.toString();});
 #endif
 }
@@ -469,7 +442,6 @@ static void maybeDump(const QString& text)
 
 void ResList::onUiPrefsChanged()
 {
-    setFont();
     displayPage();
 }
 
@@ -875,10 +847,12 @@ void ResList::append(const QString &text)
 #endif
 }
 
+const static QUrl baseUrl("file:///");
+const static std::string sBaseUrl{"file:///"};
+
 void ResList::displayPage()
 {
 #if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
-    const static QUrl baseUrl("file:///");
 
     QProgressDialog progress("Generating text snippets...", "", 0, prefs.respagesize, this);
     m_residx = 0;
@@ -888,7 +862,8 @@ void ResList::displayPage()
     m_progress = &progress;
     m_text = "";
 #else
-    clear();    
+    clear();
+    setFont();
 #endif
     
     m_pager->displayPage(theconfig);
@@ -1030,60 +1005,52 @@ void ResList::showQueryDetails()
 
 void ResList::onLinkClicked(const QUrl &qurl)
 {
-    // qt5: url.toString() does not accept FullyDecoded, but that's what we
-    // want. e.g. Suggestions links are like Sterm|spelling which we
-    // receive as Sterm%7CSpelling
-    string strurl = url_decode(qs2utf8s(qurl.toString()));
+    string strurl = pc_decode(qs2utf8s(qurl.toString()));
 
-    // Link prefix remark: it used to be that webengine refused to
-    // acknowledge link clicks on links like "%P1", it needed an
-    // absolute URL like http://localhost/P1. This does not seem to be
-    // the case any more, probably because we now set baseUrl (to fix
-    // icons display which had stopped working). So the linkprefix
-    // thing could probably go away. OTOH, we'd have to substract the
-    // baseUrl because we receive links like baseUrl+P1 instead.
-    LOGDEB1("ResList::onLinkClicked: [" << strurl << "] prefix " << m_pager->linkPrefix() << "\n");
-    if (m_pager->linkPrefix().size() > 0 &&
-        (strurl.size() <= m_pager->linkPrefix().size() ||
-         !beginswith(strurl, m_pager->linkPrefix()))) {
+    // Link prefix remark: it used to be that webengine refused to acknowledge link clicks on links
+    // like "%P1", it needed an absolute URL like file:///recoll-links/P1. So, for a time this is
+    // what the links looked like. However this broke the function of the "edit paragraph format"
+    // thing because the manual still specified relative links (E%N). We now set baseUrl to file:///
+    // to fix icons display which had stopped working). So linkprefix() is now empty, but the code
+    // has been kept around. We now receive absolute links baseUrl+relative (e.g. file:///E1), and
+    // substract the baseUrl.
+    
+#if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
+    auto prefix = m_pager->linkPrefix().size() ? m_pager->linkPrefix() : sBaseUrl;
+#else
+    std::string prefix;
+#endif
+    
+    if (prefix.size() && (strurl.size() <= prefix.size() || !beginswith(strurl, prefix))) {
+        LOGINF("ResList::onLinkClicked: bad URL [" << strurl << "] (prefix [" << prefix << "]\n");
         return;
     }
-    strurl = strurl.substr(m_pager->linkPrefix().size());
-
-    if (strurl.size() == 0) {
+    if (prefix.size()) 
+        strurl = strurl.substr(prefix.size());
+    LOGDEB("ResList::onLinkClicked: processed URL: [" << strurl << "]\n");
+    auto [what, docnum, origorscript, replacement] = internal_link(strurl);
+    if (what == 0) {
         return;
     }
-    int docnum{-1};
     bool havedoc{false};
     Rcl::Doc doc;
-    if (strurl.size() > 1) {
-        // If an integer follows interpret as doc number
-        const char *bptr = strurl.c_str() + 1;
-        char *eptr;
-        docnum = strtol(bptr, &eptr, 10) - 1;
-        if (docnum >= 0) {
-            if (getDoc(docnum, doc)) {
-                havedoc = true;
-            } else {
-                LOGERR("ResList::onLinkClicked: can't get doc for "<< docnum << "\n");
-            }
+    if (docnum >= 0) {
+        if (getDoc(docnum, doc)) {
+            havedoc = true;
+        } else {
+            LOGERR("ResList::onLinkClicked: can't get doc for "<< docnum << "\n");
         }
     }
 
-    int what = strurl[0];
     switch (what) {
-
-        // Open abstract/snippets window
-    case 'A':
-    {
+    case 'A': // Open abstract/snippets window
+    { 
         if (!havedoc)
             return;
         emit(showSnippets(doc));
     }
     break;
-
-    // Show duplicates
-    case 'D':
+    case 'D': // Show duplicates
     {
         if (!m_source || !havedoc) 
             return;
@@ -1093,26 +1060,20 @@ void ResList::onLinkClicked(const QUrl &qurl)
         }
     }
     break;
-
-    // Open parent folder
-    case 'F':
+    case 'F': // Open parent folder
     {
         if (!havedoc)
             return;
         emit editRequested(ResultPopup::getFolder(doc));
     }
     break;
-
-    // Show query details
-    case 'h':
+    case 'h': // Show query details
     case 'H':
     {
         showQueryDetails();
         break;
     }
-
-    // Preview and edit
-    case 'P': 
+    case 'P': // Preview and edit
     case 'E': 
     {
         if (!havedoc)
@@ -1128,28 +1089,20 @@ void ResList::onLinkClicked(const QUrl &qurl)
         }
     }
     break;
-
-    // Next/prev page
-    case 'n':
+    case 'n': // Next/prev page
         resultPageNext();
         break;
     case 'p':
         resultPageBack();
         break;
-
-        // Run script. Link format Rnn|Script Name
-    case 'R':
+    case 'R':// Run script. Link format Rnn|Script Name
     {
         if (!havedoc)
             return;
-        QString s = qurl.toString();
-        int bar = s.indexOf("|");
-        if (bar == -1 || bar >= s.size()-1)
-            break;
-        string cmdname = qs2utf8s(s.right(s.size() - (bar + 1)));
+        LOGERR("Run script: [" << origorscript << "]\n");
         DesktopDb ddb(path_cat(theconfig->getConfDir(), "scripts"));
         DesktopDb::AppDef app;
-        if (ddb.appByName(cmdname, app)) {
+        if (ddb.appByName(origorscript, app)) {
             QAction act(QString::fromUtf8(app.name.c_str()), this);
             QVariant v(QString::fromUtf8(app.command.c_str()));
             act.setData(v);
@@ -1158,26 +1111,17 @@ void ResList::onLinkClicked(const QUrl &qurl)
         }
     }
     break;
-
-    // Spelling: replacement suggestion clicked
-    case 'S':
+    case 'S': // Spelling: replacement suggestion clicked. strurl is like:
+        // S-1|orograpphic|orographic
     {
-        string s;
-        if (!strurl.empty())
-            s = strurl.substr(1);
-        string::size_type bar = s.find_first_of("|");
-        if (bar != string::npos && bar < s.size() - 1) {
-            string o = s.substr(0, bar);
-            string n = s.substr(bar+1);
-            LOGDEB2("Emitting wordreplace " << o << " -> " << n << std::endl);
-            emit wordReplace(u8s2qs(o), u8s2qs(n));
-        }
+        if (origorscript.empty() || replacement.empty())
+            return;
+        LOGDEB2("Emitting wordreplace " << origorscript << " -> " << replacement << "\n");
+        emit wordReplace(u8s2qs(origorscript), u8s2qs(replacement));
     }
     break;
-
     default: 
-        LOGERR("ResList::onLinkClicked: bad link [" << strurl.substr(0,20) <<
-               "]\n");
+        LOGERR("ResList::onLinkClicked: bad link [" << strurl.substr(0,20) << "]\n");
         break;
     }
 }
