@@ -103,7 +103,7 @@ private slots:
     virtual void searchTextChanged(const QString&);
     virtual void searchTextEdited(const QString&);
     virtual void onCompletionActivated(const QString&);
-    virtual void restoreText();
+    virtual void restoreText(bool startsearch=false);
     virtual void onHistoryClicked();
     virtual void onCompleterShown();
     
@@ -115,7 +115,6 @@ signals:
     void ssearchTypeChanged(int typ);
     
 private:
-    int getPartialWord(QString& word);
     bool startSimpleSearch(const std::string& q, int maxexp = -1);
     bool checkExtIndexes(const std::vector<std::string>& dbs);
 
