@@ -62,6 +62,28 @@ using std::vector;
 using std::map;
 using std::list;
 
+static std::vector<std::pair<QString, QString>> uilanguages{
+    {"", ""},    
+    {"Czech", "cs"},
+    {"Danish", "da"},
+    {"German", "de"},
+    {"Greek", "el"},
+    {"Spanish", "es"},
+    {"French", "fr"},
+    {"Hungarian", "hu"},
+    {"Italian", "it"},
+    {"Japanese", "ja"},
+    {"Korean", "ko"},
+    {"Lithuanian", "lt"},
+    {"Dutch", "nl"},
+    {"Polish", "pl"},
+    {"Russian", "ru"},
+    {"Swedish", "sv"},
+    {"Turkish", "tr"},
+    {"Ukrainian", "uk"},
+    {"Chinese", "zh_CN"},
+};
+
 void UIPrefsDialog::init()
 {
     // See enum above and keep in order !
@@ -71,13 +93,23 @@ void UIPrefsDialog::init()
     ssearchTypCMB->addItem(tr("Query language"));
     ssearchTypCMB->addItem(tr("Value from previous program exit"));
 
+    colorschemeCMB->addItem(tr("Light"));
+    colorschemeCMB->addItem(tr("Dark"));
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
+        // Qt 6.5 brings a way to detect the desktop dark/light mode.
+    colorschemeCMB->addItem(tr("System"));
+#if defined(__APPLE__)
+        // __APPLE__ with qt6.5+: always use the system mode. We have problems with the others.
+    colorschemeCMB->hide();
+#endif
+#endif
+    
     connect(viewActionPB, SIGNAL(clicked()), this, SLOT(showViewAction()));
     connect(reslistFontPB, SIGNAL(clicked()), this, SLOT(showFontDialog()));
     connect(resetFontPB, SIGNAL(clicked()), this, SLOT(resetReslistFont()));
 
     connect(stylesheetPB, SIGNAL(clicked()),this, SLOT(showStylesheetDialog()));
     connect(resetSSPB, SIGNAL(clicked()), this, SLOT(resetStylesheet()));
-    connect(darkSSPB, SIGNAL(clicked()), this, SLOT(setDarkMode()));
     connect(snipCssPB, SIGNAL(clicked()),this, SLOT(showSnipCssDialog()));
     connect(synFilePB, SIGNAL(clicked()),this, SLOT(showSynFileDialog()));
     connect(resetSnipCssPB, SIGNAL(clicked()), this, SLOT(resetSnipCss()));
@@ -96,6 +128,8 @@ void UIPrefsDialog::init()
     connect(buildAbsCB, SIGNAL(toggled(bool)), replAbsCB, SLOT(setEnabled(bool)));
     connect(autoSpellCB, SIGNAL(toggled(bool)), autoSpellMaxDistSB, SLOT(setEnabled(bool)));
     connect(ssNoCompleteCB, SIGNAL(toggled(bool)), ssSearchOnCompleteCB, SLOT(setDisabled(bool)));
+    connect(ssNoCompleteCB, SIGNAL(toggled(bool)),
+            ssearchCompletePassiveCB, SLOT(setDisabled(bool)));
     connect(ssNoCompleteCB, SIGNAL(toggled(bool)),
             showcompleterhitcountsCB, SLOT(setDisabled(bool)));
     connect(ssNoCompleteCB, SIGNAL(toggled(bool)),
@@ -181,6 +215,17 @@ void UIPrefsDialog::setFromPrefs()
     sidefilterdateformatLE->setText(prefs.sidefilterdateformat);
     ignwildsCB->setChecked(prefs.ignwilds);
     pvmaxfldlenSB->setValue(prefs.pvmaxfldlen);
+    singleappCB->setChecked(prefs.singleapp);
+    ssearchCompletePassiveCB->setChecked(prefs.ssearchCompletePassive);
+    previewLinesOverAnchorSB->setValue(prefs.previewLinesOverAnchor);
+    for (const auto& [lang,abbrev]: uilanguages) {
+        uilanguageCMB->addItem(lang, abbrev);
+    }
+    auto idx = uilanguageCMB->findData(prefs.uilanguage);
+    if (idx >= 0)
+        uilanguageCMB->setCurrentIndex(idx);
+    if (prefs.colorscheme < colorschemeCMB->count())
+        colorschemeCMB->setCurrentIndex(prefs.colorscheme);
     /*INSERTHERE_LOAD*/
 
     // See qxtconfirmationmessage. Needs to be -1 for the dialog to show.
@@ -408,7 +453,6 @@ void UIPrefsDialog::accept()
     prefs.reslistfontfamily = reslistFontFamily;
     prefs.reslistfontsize = reslistFontSize;
     prefs.darkMode = darkMode;
-    prefs.setupDarkCSS();
     prefs.qssFile = qssFile;
     prefs.snipCssFile = snipCssFile;
     prefs.reslistformat =  paraFormat;
@@ -465,6 +509,11 @@ void UIPrefsDialog::accept()
     prefs.sidefilterdateformat = sidefilterdateformatLE->text();
     prefs.ignwilds = ignwildsCB->isChecked();
     prefs.pvmaxfldlen = pvmaxfldlenSB->value();
+    prefs.singleapp = singleappCB->isChecked();
+    prefs.ssearchCompletePassive = ssearchCompletePassiveCB->isChecked();
+    prefs.previewLinesOverAnchor = previewLinesOverAnchorSB->value();
+    prefs.uilanguage = uilanguageCMB->currentData().toString();
+    prefs.colorscheme = colorschemeCMB->currentIndex();
     /*INSERTHERE_ACCEPT*/
 
     // -1 is the qxtconf... predefined value to show the dialog
@@ -581,9 +630,8 @@ void UIPrefsDialog::showFontDialog()
 
 void UIPrefsDialog::setSSButState()
 {
-    darkSSPB->setEnabled(!darkMode);
-    resetSSPB->setEnabled(darkMode || !qssFile.isEmpty());
-    if (darkMode || qssFile.isEmpty()) {
+    resetSSPB->setEnabled(!qssFile.isEmpty());
+    if (qssFile.isEmpty()) {
         stylesheetPB->setText(tr("Choose QSS File"));
     } else {
         stylesheetPB->setText(path2qs(path_getsimple(qs2path(qssFile))));
@@ -599,13 +647,6 @@ void UIPrefsDialog::showStylesheetDialog()
     }
     setSSButState();
 }
-void UIPrefsDialog::setDarkMode()
-{
-    auto fn = path_cat(path_cat(theconfig->getDatadir(), "examples"), "recoll-dark.qss");
-    qssFile = u8s2qs(fn);
-    darkMode = true;
-    setSSButState();
-}
 void UIPrefsDialog::resetStylesheet()
 {
     qssFile.clear();
