@@ -21,6 +21,10 @@
 #include "sortseq.h"
 #include "log.h"
 #include "internfile.h"
+#include "rcldb.h"
+
+using std::string;
+using std::vector;
 
 std::mutex DocSequence::o_dblock;
 string DocSequence::o_sort_trans;
