@@ -1,4 +1,4 @@
-/* Copyright (C) 2008 J.F.Dockes
+/* Copyright (C) 2008-2025 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -75,8 +75,7 @@ public:
         : m_fld(docfToDatf(f) + "=") {
         if (m_fld == "dmtime=") {
             m_ismtime = true;
-        } else if (m_fld == "fbytes=" || m_fld == "dbytes=" || 
-                   m_fld == "pcbytes=") {
+        } else if (m_fld == "fbytes=" || m_fld == "dbytes=" || m_fld == "pcbytes=") {
             m_issize = true;
         } else if (m_fld == "mtype=") {
             m_ismtype = true;
@@ -180,8 +179,6 @@ void Query::setSortBy(const string& fld, bool ascending) {
             (m_sortAscending ? "ascending" : "descending") << "\n");
 }
 
-static const string parent_prefix{"F"};
-
 class SubdocDecider : public Xapian::MatchDecider {
 public:
     SubdocDecider(bool sel) : MatchDecider(), m_select(sel) {}
@@ -246,10 +243,8 @@ bool Query::setQuery(std::shared_ptr<SearchData> sdata)
                     m_sorter = nullptr;
                 }
                 m_sorter = new QSorter(m_sortField);
-                // It really seems there is a xapian bug about sort order, we 
-                // invert here.
-                m_nq->xenquire->set_sort_by_key((QSorter*)m_sorter, 
-                                                !m_sortAscending);
+                // It really seems there is a xapian bug about sort order, we invert here.
+                m_nq->xenquire->set_sort_by_key((QSorter*)m_sorter, !m_sortAscending);
             }
             m_nq->xenquire->set_query(m_nq->xquery);
             m_nq->xmset = Xapian::MSet();
@@ -288,8 +283,7 @@ bool Query::getQueryTerms(vector<string>& terms)
     Xapian::TermIterator it;
     string ermsg;
     try {
-        for (it = m_nq->xquery.get_terms_begin(); 
-             it != m_nq->xquery.get_terms_end(); it++) {
+        for (it = m_nq->xquery.get_terms_begin(); it != m_nq->xquery.get_terms_end(); it++) {
             terms.push_back(*it);
         }
     } XCATCHERROR(ermsg);
@@ -300,6 +294,33 @@ bool Query::getQueryTerms(vector<string>& terms)
     return true;
 }
 
+bool Query::getDocTerms(const Doc& doc, vector<vector<string>>& oterms)
+{
+    if (!m_db || !m_db->m_ndb || !m_db->m_ndb->m_isopen || !m_nq) {
+        return false;
+    }
+
+    oterms.clear();
+    auto docid = doc.xdocid;
+    vector<string> matchterms;
+    m_nq->getMatchTerms(docid, matchterms);
+    if (matchterms.empty()) {
+        LOGDEB("getDocTerms: empty match term list (field match?)\n");
+        return false;
+    }
+    multimap<double, vector<string> > byQ;
+    m_nq->qualityTerms(docid, matchterms, byQ);
+    if (byQ.empty()) {
+        LOGDEB("qualityTerms returned no terms for docid " << docid << " input terms " <<
+               stringsToString(matchterms) << "\n");
+        return -1;
+    }
+    for (auto mit = byQ.rbegin(); mit != byQ.rend(); mit++) {
+        oterms.push_back(mit->second);
+    }
+    return true;
+}
+
 int Query::makeDocAbstract(const Doc &doc, PlainToRich *plaintorich, vector<Snippet>& abstract, 
                            int maxoccs, int ctxwords, bool sortbypage)
 {
@@ -322,8 +343,8 @@ int Query::makeDocAbstract(const Doc &doc, PlainToRich *plaintorich, vector<Snip
     for (auto& snip : abs1) {
         list<string> ls;
         if (plaintorich->plaintorich(snip.snippet, ls, hldata)) {
-          snip.snippet = ls.front();
-          abstract.push_back(snip);
+            snip.snippet = ls.front();
+            abstract.push_back(snip);
         }
     }
     return ret;
@@ -421,13 +442,11 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
     }
 
     int first = m_nq->xmset.get_firstitem();
-    int last = first + m_nq->xmset.size() -1;
 
-    if (!(xapi >= first && xapi <= last)) {
+    if (!(xapi >= first && xapi <= first + int(m_nq->xmset.size()) -1)) {
         LOGDEB("Fetching for first " << xapi << ", count " << qquantum << "\n");
 
-        XAPTRY(m_nq->xmset = m_nq->xenquire->get_mset(
-                   xapi, qquantum, nullptr, m_nq->subdecider),
+        XAPTRY(m_nq->xmset = m_nq->xenquire->get_mset(xapi, qquantum, nullptr, m_nq->subdecider),
                m_db->m_ndb->xrdb, m_reason);
         if (!m_reason.empty()) {
             LOGERR("enquire->get_mset: exception: " << m_reason << "\n");
@@ -438,7 +457,6 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
             return false;
         }
         first = m_nq->xmset.get_firstitem();
-        last = first + m_nq->xmset.size() -1;
     }
 
     Xapian::Document xdoc;
@@ -446,9 +464,8 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
     int pc = 0;
     int collapsecount = 0;
     string data;
-    string udi;
     m_reason.erase();
-    for (int xaptries=0; xaptries < 2; xaptries++) {
+    for (int xaptries = 0; xaptries < 2; xaptries++) {
         try {
             xdoc = m_nq->xmset[xapi-first].get_document();
             collapsecount = m_nq->xmset[xapi-first].get_collapse_count();
@@ -456,10 +473,6 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
             pc = m_nq->xmset.convert_to_percent(m_nq->xmset[xapi-first]);
             data = xdoc.get_data();
             m_reason.erase();
-            Chrono chron;
-            m_db->m_ndb->xdocToUdi(xdoc, udi);
-            LOGDEB2("Query::getDoc: " << chron.millis() << " ms for udi [" <<
-                    udi << "], collapse count " << collapsecount << "\n");
             break;
         } catch (Xapian::DatabaseModifiedError &error) {
             // retry or end of loop
@@ -473,7 +486,6 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
         LOGERR("Query::getDoc: " << m_reason << "\n");
         return false;
     }
-    doc.meta[Rcl::Doc::keyudi] = udi;
 
     doc.pc = pc;
     char buf[200];
@@ -490,7 +502,7 @@ bool Query::getDoc(int xapi, Doc &doc, bool fetchtext)
     }
 
     // Parse xapian document's data and populate doc fields
-    return m_db->m_ndb->dbDataToRclDoc(docid, data, doc, fetchtext);
+    return m_db->m_ndb->dbDataToRclDoc(docid, xdoc, data, doc, fetchtext);
 }
 
 vector<string> Query::expand(const Doc &doc)
@@ -537,4 +549,3 @@ vector<string> Query::expand(const Doc &doc)
 }
 
 }
-
