@@ -21,15 +21,13 @@
 
 #include <memory>
 
-#include "searchdata.h"
-#include "plaintorich.h"
+class PlainToRich;
 
-#ifndef NO_NAMESPACES
 namespace Rcl {
-#endif
 
 class Db;
 class Doc;
+class SearchData;
 
 enum abstract_result {
     ABSRES_ERROR = 0,
@@ -112,6 +110,8 @@ public:
     /** Get possibly expanded list of query terms */
     bool getQueryTerms(std::vector<std::string>& terms);
 
+    bool getDocTerms(const Doc& doc, std::vector<std::vector<std::string>>& terms);
+    
     /** Build synthetic abstract for document, extracting chunks relevant for
      * the input query. This uses index data only (no access to the file) 
      */
@@ -163,9 +163,6 @@ private:
     int    m_snipMaxPosWalk{1000000};
 };
 
-#ifndef NO_NAMESPACES
 }
-#endif // NO_NAMESPACES
-
 
 #endif /* _rclquery_h_included_ */
