@@ -33,9 +33,14 @@
 #include "rcldoc.h"
 #include "syngroups.h"
 #include "fileudi.h"
+#ifdef RCL_USE_ASPELL
+#include "rclaspell.h"
+#endif
 
 using namespace std;
 
+#define LOGTERM LOGDEB1
+
 namespace Rcl {
 
 // File name wild card expansion. This is a specialisation ot termMatch
@@ -425,7 +430,7 @@ bool Db::Native::idxTermMatch_p(int typ, const string& expr, const std::string&
                                 std::function<bool(const string& term, Xapian::termcount colfreq,
                                                    Xapian::doccount termfreq)> client)
 {
-    LOGDEB1("idxTermMatch_p: input expr: [" << expr << "] prefix [" << prefix << "]\n");
+    LOGTERM("idxTermMatch_p: input expr: [" << expr << "] prefix [" << prefix << "]\n");
 
     Xapian::Database xdb = xrdb;
 
@@ -450,7 +455,7 @@ bool Db::Native::idxTermMatch_p(int typ, const string& expr, const std::string&
     } else {
         is = prefix + expr;
     }
-    LOGDEB1("idxTermMatch_p: initial section: [" << is << "]\n");
+    LOGTERM("idxTermMatch_p: initial section: [" << is << "]\n");
 
     XAPTRY(
         Xapian::TermIterator it = xdb.allterms_begin(is);
@@ -459,7 +464,7 @@ bool Db::Native::idxTermMatch_p(int typ, const string& expr, const std::string&
             LOGDEB1("idxTermMatch_p: term at skip [" << ixterm << "]\n");
             // If we're beyond the terms matching the initial section, end.
             if (!is.empty() && ixterm.find(is) != 0) {
-                LOGDEB1("idxTermMatch_p: initial section mismatch: stop\n");
+                LOGTERM("idxTermMatch_p: initial section mismatch: stop\n");
                 break;
             }
             // Else try to match the term. The matcher content is prefix-less.
@@ -470,6 +475,7 @@ bool Db::Native::idxTermMatch_p(int typ, const string& expr, const std::string&
                 if (has_prefix(ixterm)) {
                     // This is possible with a left-side wildcard which would have an empty
                     // initial section so that we're scanning the whole term list.
+                    LOGTERM("Skipping prefixed term [" << ixterm << "]\n");
                     continue;
                 }
                 term = ixterm;
@@ -479,12 +485,14 @@ bool Db::Native::idxTermMatch_p(int typ, const string& expr, const std::string&
             // equality
             if (matcher) {
                 if (!matcher->match(term)) {
+                    LOGTERM("No match for <" << term << "> exp <" << matcher->exp() << ">\n");
                     continue;
                 }
             } else if (term != expr) {
                 break;
             }
 
+            LOGTERM("match for [" << ixterm << "]\n");
             if (!client(ixterm, xdb.get_collection_freq(ixterm), it.get_termfreq()) || !matcher) {
                 // If the client tells us or this is an exact search, stop.
                 break;
@@ -704,4 +712,105 @@ bool Db::stemDiffers(const string& lang, const string& word,
     return true;
 }
 
+bool Db::isSpellingCandidate(const std::string& term, bool with_aspell)
+{
+    if (term.empty() || term.length() > 50 || has_prefix(term))
+        return false;
+
+    Utf8Iter u8i(term);
+    if (with_aspell) {
+        // If spelling with aspell, CJK and other scripts we process with ngrams are not
+        // candidates. Same test as for stemming.
+        if (TextSplit::noStemming(*u8i))
+            return false;
+    } else {
+#ifdef TESTING_XAPIAN_SPELL
+        // The Xapian speller (purely proximity-based) can be used for Katakana (when split as words
+        // which is not always completely feasible because of separator-less compounds). Currently
+        // we don't try to use the Xapian speller with other scripts with which it would be usable
+        // in the absence of aspell (it would indeed be better than nothing with e.g. european
+        // languages). This would require a few more config variables, maybe one day.
+        if (!TextSplit::isKATAKANA(*u8i)) {
+            return false;
+        }
+#else
+        return false;
+#endif
+    }
+
+    // Most punctuation chars inhibate stemming. We accept one dash. See o_nospell_chars init in
+    // the rcldb constructor.
+    int ccnt = 0;
+    for (unsigned char c : term) {
+        if (o_nospell_chars[(unsigned int)c] && (c != '-' || ++ccnt > 1))
+            return false;
+    }
+
+    return true;
+}
+
+// At the moment, we only use aspell. The xapian speller code part is only for testing and normally
+// not compiled in.
+bool Db::getSpellingSuggestions(const string& word, vector<string>& suggs)
+{
+    LOGDEB("Db::getSpellingSuggestions:[" << word << "]\n");
+    suggs.clear();
+    if (nullptr == m_ndb) {
+        return false;
+    }
+
+    string term = word;
+
+    if (isSpellingCandidate(term, true)) {
+        // Term is candidate for aspell processing
+#ifdef RCL_USE_ASPELL
+        bool noaspell = false;
+        m_config->getConfParam("noaspell", &noaspell);
+        if (noaspell) {
+            return false;
+        }
+        if (nullptr == m_aspell) {
+            m_aspell = new Aspell(m_config);
+            if (m_aspell) {
+                string reason;
+                m_aspell->init(reason);
+                if (!m_aspell->ok()) {
+                    LOGDEB("Aspell speller init failed: " << reason << "\n");
+                    delete m_aspell;
+                    m_aspell = nullptr;
+                }
+            }
+        }
+
+        if (nullptr == m_aspell) {
+            LOGERR("Db::getSpellingSuggestions: aspell not initialized\n");
+            return false;
+        }
+
+        string reason;
+        if (!m_aspell->suggest(*this, term, suggs, reason)) {
+            LOGERR("Db::getSpellingSuggestions: aspell failed: " << reason << "\n");
+            return false;
+        }
+#endif
+    } else {
+#ifdef TESTING_XAPIAN_SPELL
+        // Was not aspell candidate (e.g.: katakana). Maybe use Xapian speller?
+        if (isSpellingCandidate(term, false)) {
+            if (!o_index_stripchars) {
+                if (!unacmaybefold(word, term, UNACOP_UNACFOLD)) {
+                    LOGINFO("Db::getSpelling: unac failed for [" << word << "]\n");
+                    return false;
+                }
+            }
+            string sugg = m_ndb->xrdb.get_spelling_suggestion(term);
+            if (!sugg.empty()) {
+                suggs.push_back(sugg);
+            }
+        }
+#endif
+    }
+    return true;
+}
+
 } // End namespace Rcl
