@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 J.F.Dockes
+/* Copyright (C) 2004-2024 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -15,18 +15,17 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <conftree.h>
-#include <fstreewalk.h>
-
-#include <iostream>
-using namespace std;
-
-#include "pathut.h"
-#include "smallut.h"
 #include "appformime.h"
 
-static const string topappsdir("/usr/share/applications");
-static const string desktopext("desktop");
+#include <iostream>
+
+#include "conftree.h"
+#include "fstreewalk.h"
+#include "pathut.h"
+#include "smallut.h"
+
+static const std::string topappsdir("/usr/share/applications");
+static const std::string desktopext("desktop");
 
 static DesktopDb *theDb;
 
@@ -35,54 +34,52 @@ public:
     FstCb(DesktopDb::AppMap *appdefs)
         : m_appdefs(appdefs) {}
     virtual FsTreeWalker::Status 
-    processone(const string &, FsTreeWalker::CbFlag, const struct PathStat&) override;
+    processone(const std::string &, FsTreeWalker::CbFlag, const struct PathStat&) override;
     DesktopDb::AppMap *m_appdefs;
 };
 
 FsTreeWalker::Status FstCb::processone(
-    const string& fn, FsTreeWalker::CbFlag flg, const struct PathStat&)
+    const std::string& fn, FsTreeWalker::CbFlag flg, const struct PathStat&)
 {
     if (flg != FsTreeWalker::FtwRegular)
         return FsTreeWalker::FtwOk;
 
-    if (path_suffix(fn).compare(desktopext)) {
-        //cerr << fn << " does not end with .desktop" << endl;
+    if (path_suffix(fn) != desktopext) {
+        //cerr << fn << " does not end with .desktop" << '\n';
         return FsTreeWalker::FtwOk;
     }
 
     ConfSimple dt(fn.c_str(), true);
     if (!dt.ok()) {
-        cerr << fn << " cant parse" << endl;
+        std::cerr << fn << " cant parse" << '\n';
         return FsTreeWalker::FtwOk;
     }
-    string tp, nm, cmd, mt;
+    std::string tp, nm, cmd, mt;
     if (!dt.get("Type", tp, "Desktop Entry")) {
-        //cerr << fn << " no Type" << endl;
+        //std::cerr << fn << " no Type" << '\n';
         return FsTreeWalker::FtwOk;
     }
-    if (tp.compare("Application")) {
-        //cerr << fn << " wrong Type " << tp << endl;
+    if (tp != "Application") {
+        //std::cerr << fn << " wrong Type " << tp << '\n';
         return FsTreeWalker::FtwOk;
     }
     if (!dt.get("Exec", cmd, "Desktop Entry")) {
-        //cerr << fn << " no Exec" << endl;
+        //std::cerr << fn << " no Exec" << '\n';
         return FsTreeWalker::FtwOk;
     }
     if (!dt.get("Name", nm, "Desktop Entry")) {
-        //cerr << fn << " no Name" << endl;
+        //std::cerr << fn << " no Name" << '\n';
         nm = path_basename(fn, desktopext);
     }
     if (!dt.get("MimeType", mt, "Desktop Entry")) {
-        //cerr << fn << " no MimeType" << endl;
+        //std::cerr << fn << " no MimeType" << '\n';
         return FsTreeWalker::FtwOk;
     }
-    DesktopDb::AppDef appdef(nm, cmd);
     // Breakup mime type list, and push app to mime entries
-    vector<string> mimes;
+    std::vector<std::string> mimes;
     stringToTokens(mt, mimes, ";");
-    for (vector<string>::const_iterator it = mimes.begin();
-         it != mimes.end(); it++) {
-        (*m_appdefs)[*it].push_back(appdef);
+    for (const auto& mime: mimes) {
+        (*m_appdefs)[mime].emplace_back(nm, cmd);
     }
     return FsTreeWalker::FtwOk;
 }
@@ -97,7 +94,7 @@ DesktopDb* DesktopDb::getDb()
     return nullptr;
 }
 
-void DesktopDb::build(const string& dir)
+void DesktopDb::build(const std::string& dir)
 {
     FstCb procapp(&m_appMap);
     FsTreeWalker walker;
@@ -113,51 +110,43 @@ DesktopDb::DesktopDb()
     build(topappsdir);
 }
 
-DesktopDb::DesktopDb(const string& dir)
+DesktopDb::DesktopDb(const std::string& dir)
 {
     build(dir);
 }
 
-bool DesktopDb::appForMime(const string& mime, vector<AppDef> *apps, 
-                           string *reason)
+bool DesktopDb::appForMime(const std::string& mime, std::vector<AppDef> *apps, std::string *reason)
 {
-    AppMap::const_iterator it = m_appMap.find(mime);
+    auto it = m_appMap.find(mime);
     if (it == m_appMap.end()) {
         if (reason)
-            *reason = string("No application found for ") + mime;
+            *reason = std::string("No application found for ") + mime;
         return false;
     }
     *apps = it->second;
     return true;
 }
 
-bool DesktopDb::allApps(vector<AppDef> *apps)
+bool DesktopDb::allApps(std::vector<AppDef> *apps)
 {
-    map<string, AppDef> allaps;
-    for (AppMap::const_iterator it = m_appMap.begin();
-         it != m_appMap.end(); it++) {
-        for (vector<AppDef>::const_iterator it1 = it->second.begin();
-             it1 != it->second.end(); it1++) {
-            allaps.insert(pair<string, AppDef>
-                          (it1->name, AppDef(it1->name, it1->command)));
+    std::set<AppDef> allaps;
+    for (const auto& mimeapps : m_appMap) {
+        for (const auto& app : mimeapps.second) {
+            allaps.insert(app);
         }
     }
-    for (map<string, AppDef>::const_iterator it = allaps.begin();
-         it != allaps.end(); it++) {
-        apps->push_back(it->second);
+    for (const auto& app : allaps) {
+        apps->emplace_back(app.name, app.command);
     }
     return true;
 }
 
-bool DesktopDb::appByName(const string& nm, AppDef& app)
+bool DesktopDb::appByName(const std::string& nm, AppDef& appout)
 {
-    for (AppMap::const_iterator it = m_appMap.begin();
-         it != m_appMap.end(); it++) {
-        for (vector<AppDef>::const_iterator it1 = it->second.begin();
-             it1 != it->second.end(); it1++) {
-            if (!nm.compare(it1->name)) {
-                app.name = it1->name;
-                app.command = it1->command;
+    for (const auto& mimeapps : m_appMap) {
+        for (const auto& app : mimeapps.second) {
+            if (nm == app.name) {
+                appout = app;
                 return true;
             }
         }
@@ -165,7 +154,7 @@ bool DesktopDb::appByName(const string& nm, AppDef& app)
     return false;
 }
 
-const string& DesktopDb::getReason()
+const std::string& DesktopDb::getReason()
 {
     return m_reason;
 }
