@@ -62,7 +62,6 @@
 #include <map>
 #include <sstream>
 #include <iostream>
-#include <algorithm>
 
 // Expat compat
 typedef char XML_Char;
@@ -152,7 +151,7 @@ private:
 
     void _startelem(const std::string& tagname,
                     const std::map<std::string, std::string>& attrs, bool empty) {
-        m_path.push_back(StackEl(tagname));
+        m_path.emplace_back(tagname);
         StackEl& lastelt = m_path.back();
         lastelt.start_index = m_pos;
         lastelt.attributes = attrs;
@@ -255,7 +254,6 @@ private:
             } else {
                 _startelem(tag, attrs, emptyel);
             }
-            spos = m_pos;
             if (!_chardata()) {
                 return false;
             }
@@ -275,7 +273,7 @@ private:
                 return false;
             }
             characterData(data);
-            CharacterData(data.c_str(), data.size());
+            CharacterData(data.c_str(), static_cast<int>(data.size()));
         }
         return true;
     }
@@ -303,10 +301,9 @@ private:
         return m_in[m_pos + 1 + sz];
     }
     void trimtag(std::string& tag) {
-        std::string::size_type trimpos = tag.find_last_not_of(" \t\n\r");
-        if (trimpos != std::string::npos) {
-            tag = tag.substr(0, trimpos+1);
-        }
+        auto trimpos = tag.find_last_not_of(" \t\n\r");
+        if (trimpos != std::string::npos)
+            tag.resize(trimpos + 1);
     }
 
     bool skipDecl() {
@@ -436,7 +433,7 @@ private:
             }
             // Position: m_pos minus the string size (including 2 quotes) plus position inside s
             epos = m_pos - (s.size() + 2) + it - s.begin();
-            it++;
+            ++it;
             std::string code;
             while (it != s.end() && *it != ';') {
                 code += *it++;
@@ -448,7 +445,7 @@ private:
                 out.clear();
                 break;
             }
-            it++;
+            ++it;
             if (code == e_quot) {
                 out += '"';
             } else if (code == e_amp) {
